<?php
/**
 * Scand_ProductLocator extension is a extension to display specific products on Product Locator.
 * Copyright (C) 2013 Scand Ltd.
 * 
 * This file is part of Scand_ProductLocator extension.
 * 
 * Scand_ProductLocator extension is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Scand_ProductLocator extension is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Scand_ProductLocator extension. If not, see <http://www.gnu.org/licenses/>.
 * 
 * @category    Scand
 * @package     Scand_ProductLocator
 * @copyright   Copyright (c) 2013 Scand Ltd. (http://www.scand.com)
 * @license     http://www.gnu.org/licenses/gpl-3.0.html GNU General Public License (GPL 3.0)
 */

class Scand_ProductLocator_Block_Adminhtml_Catalog_Product_Edit_Tab_Productlocator
extends Mage_Adminhtml_Block_Widget_Form
implements Mage_Adminhtml_Block_Widget_Tab_Interface
{
	public function _construct() {
		parent::_construct();
		$this->setTemplate('productlocator/catalog/product/edit/tab.phtml');
	}
	
	protected function _getProduct() {
		return Mage::registry('current_product');
	}
	
	protected function _getSession() {
		return Mage::getSingleton('adminhtml/session');
	}
	
	protected function _getRequest() {
		return Mage::app()->getRequest();
	}
	
	protected function _prepareForm() {
		parent::_prepareForm();
		
		$form = new Varien_Data_Form();
		$form->setHtmlIdPrefix('productlocator_address_');
		$this->setForm($form);
		
		return $this;
	}
	
	protected function _initFormValues() {
		parent::_initFormValues();
		
		$product = $this->_getProduct();
		/*if ($product->isConfigurable())
			return $this;*/

		$form = $this->getForm();
		$fieldset = $form->addFieldset('address_fieldset', array());
		
		$addressModel = Mage::getModel('customer/address');
		$addressForm = Mage::getModel('customer/form')
			->setFormCode('product_customer_address')
			->setEntity($addressModel);

		$attributes = $addressForm->getAttributes();
		if(isset($attributes['street'])) {
			Mage::helper('adminhtml/addresses')
				->processStreetAttribute($attributes['street']);
		}

		foreach ($attributes as $attribute) {
			$attribute->unsIsVisible();
		}
		$this->_setFieldset($attributes, $fieldset);

		$aFileds = array('street','city','country_id','postcode','telephone');
		foreach ($aFileds as $fieldName) {
			$objElement = $form->getElement($fieldName);
			if ($objElement) {
				$objElement->setRequired(FALSE);
				$objElement->removeClass('required-entry');
				if ($fieldName == 'country_id') {
					$objElement->addClass('countries');
				}
			}
		}

		$regionElement = $form->getElement('region');
		if ($regionElement) {
			$regionElement->setRenderer(Mage::getModel('productlocator/product_renderer_region'));
		}
		
		$regionElement = $form->getElement('region_id');
		if ($regionElement) {
			$regionElement->setNoDisplay(true);
		}
		
		$sessionData = $this->_getSession()->getAddressFormData();
		$addressData = Mage::getModel('productlocator/product_address');

		if (empty($sessionData)) {
			$addressData->setCountryId(Mage::helper('core')->getDefaultCountry($product->getStore()))
				->loadByProduct($product->getId());
		}
		else {
			$addressData->setData($sessionData['product'][$addressData->addressFormPrefix]);
		}

		$fieldPrefix = 'product['.$addressData->addressFormPrefix.']';
		$form->addFieldNameSuffix($fieldPrefix);
		$form->setHtmlNamePrefix($fieldPrefix);
		
		$form->setValues($addressData->getData());
		$this->_form = $form;
		
		return $this;
	}
	
	public function getTabLabel() {
		return $this->__('Product Locator');
	}
	
	public function getTabTitle() {
		return $this->__('Click to view content');
	}
	
	public function canShowTab() {
		return TRUE;
	}
	
	public function isHidden() {
		return FALSE;
	}
}
